-------------------------------------------------------------------------------
-- Name: class CardReader
-- Author: Thomas Jiji
--
-- Description:
-- This Class Interact with the Card Reader 
-- through DirectComm Xtra
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
-------------------------------------------------------------------------------
property pDevice
property pPortName
property pBaudRate
property pDataBits
property pStopBits
property pParity
property pQueueSize
property pTimeOut
property pFlowControl
property pLastScan
property pBuf
property pPollOnIdle

property pStartOffset
property pEndOffset

property pBufPeriod
property pBufTimeout

-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

on new (me, CallBack)
  
  crInfo = QI(#config).GetCardReaderInfo()
  
  pPortName = crInfo.getAProp(#portName)
  pBaudRate = crInfo.getAProp(#baudRate)
  pStartOffset = crInfo.getAProp(#startOffset)
  pEndOffset = crInfo.getAProp(#endOffset)
  pBufPeriod = crInfo.getAProp(#bufTimeout)
  
  pBufTimeout = script("class Timeout").new()
  pBufTimeout.ResetHit()
  pBufTimeout.SetName("to,BufTimeout")
  pBufTimeout.SetTimeout(pBufPeriod)
  pBufTimeout.SetHitScale(1000)
  pBufTimeout.SetTimeoutCallback(#ReadBuf, me)
  
  pDataBits = 8
  pStopBits = 1
  pParity   = 0
  pQueueSize= 4096
  pTimeOut  = 3000
  pFlowControl = 0
  pBuf =""
  pLastScan = 0
  pPollOnIdle = false
  
  -- Initialize
  me._Init()
  
  return(me)
end

on Destroy (me)
  Error = commDisconnect(pDevice)
  if (Error) then
    alert ("Could not disconnect from the device. Error #"&Error)
  end if  
  pDevice = 0
end

on StartPolling me
  pPollOnIdle = true
end

on StopPolling me
  pPollOnIdle = false
end

on CheckReader()
  if (pPollOnIdle) then
    count = commCountCharsInQueue(pDevice, 0)
    if (count > 0) then
      pBufTimeout.Start()
      StopPolling()
    end if    
  end if  
end

on ReadBuf()
  pBufTimeout.Stop()
  pBuf = commRead(pDevice)
  if (pBuf <> VOID AND pBuf <>"") then
    put pBuf
    Parse()
    HandleThisNum(pLastScan)
  end if
  StartPolling()
end


on HandleThisNum(num)
  
  -- Check Status to know where to foward this information
  state = QI(#status).getStatus()
  
  if state[#login] = "N/A" then
    QI(#Login).GoToLogin()
    QI(#SCGLogin).Show(0,0, num)
    QI(#status).setStatus(#login, "Swiped")
  else if state[#login] = "Swiped" then
    QI(#SCGLogin).Hide()
    QI(#SCGLogin).Show(0,0, num)
  else if state[#login] = "TouchScreen" then
    QI(#SCGLogin).Hide()
    QI(#SCGLogin).Show(0,0, num)
  end if
  
end

on Parse ()
  
  pLastScan = pBuf.char[pStartOffset..pEndOffset]
  
  -- Assuming that Number is between the "=" and "=====" 
  -- In this case ->"%24=86619=====738?", num=86619 
  --  str = pBuf
  --  leftLimit = offset("=", str)+1
  --  str = str.char[leftLimit..(str.length)]
  --  
  --  rightLimit = offset("=", str)-1
  --  str = str.char[1..rightLimit]
  --  pLastScan = Integer(str)
  
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

on _Init (me)
  
  -- Create a new instance of DirectCommunication Xtra and store it in a member variable 
  -- for a later user. 
  pDevice = new (Xtra "DirectCommunication", 316926650)
  
  Error = commConnect (pDevice, pPortName)
  if (Error) then
    alert ("Can't connect to card Reader on port:"&& pPortName)
  else
    ApplyDeviceSettings()
  end if
end

on ApplyDeviceSettings
  
  -- Set the baud rate
  set Error = commSetBaudRate (pDevice, pBaudRate)
  if (Error) then
    alert ("Can't set the baud rate. Error # "&Error)
  end if
  
  -- Set the data bits
  set Error = commSetDataBits (pDevice, pDataBits)
  if (Error) then
    alert ("Can't set the data bits. Error # "&Error)
  end if
  
  -- Set the stop bits
  set Error = commSetStopBits (pDevice, pStopBits)
  if (Error) then
    alert ("Can't set the stop bits. Error # "&Error)
  end if
  
  -- Set the parity
  set Error = commSetParity (pDevice, pParity)
  if (Error) then
    alert ("Can't set the parity. Error # "&Error)
  end if
  
  -- Set the input buffer size
  set Error = commSetQueueSize (pDevice, pQueueSize, commGetQueueSize(pDevice, 1))
  -- Ignore 13005 error to avoid the error message since this function is not available on MacOS X.
  if (Error) and (Error<>13005) then
    alert ("Can't set the queue size. Error # "&Error)
  end if
  
  -- Set the time-out
  set Error = commSetTimeOut (pDevice, pTimeOut)
  -- Ignore 13005 error to avoid the error message since this function is not available on MacOS classic.
  if (Error) and (Error<>13005) then
    alert ("Can't set the time-out. Error # "&Error)
  end if
  
  -- Set the flow control
  set Error = commSetFlowControl (pDevice, pFlowControl)
  if (Error) then
    alert ("Can't set the flow control. Error # "&Error)
  end if
  
end

