-------------------------------------------------------------------------------
-- Name: class HeartBeatTimeout
-- Author: Thomas Jiji
--
-- Description:
--     Takes care of creating an automatic heartbeat activity log event.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
------------------------------------------------------------------------------- 

property ancestor              -- Parent

-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class Timeout").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on Start (me)
  GenLog(#debug, "HeartBeatTimeout::Start: Restarting timer...")
  
  me.ResetHit()
  me.SetName("to,heartbeat")
  me.SetHitScale(1000) -- 1 second
  
  me.SetHitCallback(#_HitCallback, me)
  me.SetTimeoutCallback(#_TimeoutCallback, me)
  
  if (ancestor.Start() = true) then
    GenLog(#debug, "HeartBeatTimeout::Start: Timer restarted!")
  else 
    GenLog(#error, "HeartBeatTimeout::Start: Timer NOT restarted!")
  end if
end

-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
end

on _HitCallback (me)
end

on _TimeoutCallback (me)
  me.start()
  ACTLOG(#heartbeat, "Im Alive in this area ", QI(#status).GetStatus().area) 
  GenLog(#debug, "HeartBeatTimeout::_TimeoutCallback: Im Alive!")
end