-------------------------------------------------------------------------------
-- Name: class Login
-- Author: Jonathan Primeau
--
-- Description:
--     This class manages the login sequence.
--
------------------------------------------------------------------------------- 

-------------------------------------------------------------------------------
-- P R O P E R T I E S
-------------------------------------------------------------------------------

property ancestor              -- Parent
property pIsPatronLogin
property pShowLoginScreen
property pDoBeginSession


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class XMLParser").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on OpenLogin (me)
  GenLog(#debug, "Login::OpenLogin:")
  --QI(#ebLogin).Show()
end

on CheckForLoginScreen (me)
  if (me.pShowLoginScreen = true) then
    me.OpenLogin()
    me.pShowLoginScreen = false
  end if
end

on CloseLogin (me)
  GenLog(#debug, "Login::CloseLogin:")
  QI(#SCGLogin).Hide()
  if (me.pDoBeginSession = true) then
    me.BeginSession()
  else
    QI(#patron).SetPatronLogout()
  end if
end

on BeginTryout (me)
  GenLog(#debug, "Login::BeginTryout:")
  -- Tryout login
  me.pIsPatronLogin = false
  
  QI(#status).SetStatus(#login, "Tryout")
  QI(#patron).SetPatronTryout()
  
  QI(#appTimeout).Start()
  
  ActLog(#patron, "Tryout", "Patron logged in (in tryout mode)")
  
  me.GoToHome()
end

on Logout (me)
  GenLog(#debug, "Login::Logout:")
  QI(#SCGCommunicator).LogoutChallenge()
  
  me._ClearSession()
  
  if (me.pIsPatronLogin = true) then
    GenLog(#debug, "Login::Logout: me.pIsPatronLogin = true")
    QI(#patron).SetPatronLogout()
    me.GoToLogout()
  else
    GenLog(#debug, "Login::Logout: me.pIsPatronLogin = false")
    
    me.GoToLogin()
    
    ActLog(#patron, "Logout", "Patron logged out (from tryout mode)")
  end if
  
  QI(#status).SetStatus(#login, "N/A")
end

-- JP NO ENTERBET
on LogoutNoEnterbet (me)
  GenLog(#debug, "Login::LogoutNoEnterbet:")
  
  me._ClearSession()
  
  me.GoToAttractLoop()
  QI(#SCGCommunicator).LogoutChallenge()
  QI(#status).SetStatus(#login, "N/A")
end

-- JP NO ENTERBET
on BeginSessionNoEnterbet (me)
  GenLog(#debug, "Login::BeginSessionNoEnterbet:")
  
  -- Close Login Window
  QI(#SCGLogin).CloseWindow()
  
  -- Clearing history
  QI(#nav).ClearHistory()
  
  QI(#status).SetStatus(#login, "SCG")
  QI(#patron).SetPatronTryout()
  
  QI(#appTimeout).Start()
  
  -- Patron logged in
  me.pIsPatronLogin = false
  
  ActLog(#patron, "Login", "Patron logged in (NEB mode)")
  
  QI(#crm).CheckCrmOffer("interstitial", #_CrmInitialOfferCallback, me)
end

on BeginSession (me)
  GenLog(#debug, "Login::BeginSession:")
  
  -- Clearing history
  QI(#nav).ClearHistory()
  
  QI(#status).SetStatus(#login, "TSC")
  QI(#appTimeout).Start()
  
  -- Patron logged in
  me.pIsPatronLogin = true
  
  ActLog(#patron, "Login", "Patron logged in (in TCS mode)")
  
  QI(#crm).CheckCrmOffer("interstitial", #_CrmInitialOfferCallback, me)
end

on EndSession (me)
  GenLog(#debug, "Login::EndSession:")
  -- Patron logout
  me._ClearSession()
  
  me.GoToLogin()
  
  -- Patron logged out
  me.pIsPatronLogin = false
end

on GoToOffer (me)
  GenLog(#debug, "Login::GoToOffer:")
  lTarget = "ogn://navigate/offer"
  QI(#nav).Navigate(lTarget, false)
end

on GoToLogin (me, theLoginScreen)
  -- Only if we are not currently logging in
  if (me.pDoBeginSession = false) then
    if (theLoginScreen = true) then
      me.pShowLoginScreen = true
    end if
    GenLog(#debug, "Login::GoToLogin:")
    lTarget = "ogn://navigate/login"
    QI(#nav).Navigate(lTarget, false)
  end if
end

on GoToHome (me)
  GenLog(#debug, "Login::GoToHome:")
  lTarget = "ogn://navigate/home"
  QI(#nav).Navigate(lTarget, true)
end

on GoToAttractLoop (me)
  GenLog(#debug, "Login::GoToAttractLoop:")
  lTarget = "ogn://navigate/attract_loop"
  QI(#nav).Navigate(lTarget, false)
end

on GoToLogout (me)
  GenLog(#debug, "Login::GoToLogout:")
  lTarget = "ogn://navigate/logout"
  QI(#nav).Navigate(lTarget, false)
end

on SetDoBeginSession (me, theState)
  me.pDoBeginSession = theState
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pIsPatronLogin = false
  me.pShowLoginScreen = false
  me.SetDoBeginSession(false)
end

on _CrmInitialOfferCallback (me, theState)
  GenLog(#debug, "Login::CheckCRMInitialOffer:")
  
  if (theState = true) then
    me.GoToOffer()
  else
    me.GoToHome()
  end if
  
  -- End of begin session
  me.SetDoBeginSession(false)
end

on _ClearSession (me)
  -- Let everybody know that a logout occured
  QI(#events).Trigger(#onTimeout, [])
  
  QI(#appTimeout).Stop()
  
  -- Stop banner cycling
  QI(#banner).StopCycling()
  
  -- Clearing history
  QI(#nav).ClearHistory()
end