-------------------------------------------------------------------------------
-- Name: class NavTimeout
-- Author: Jonathan Primeau
--
-- Description:
--     Takes care of the navigation.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
------------------------------------------------------------------------------- 

property ancestor              -- Parent
property pTarget
property pHistory


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class Timeout").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on Start (me)
  GenLog(#debug, "NavTimeout::Start: Starting timer...")
  
  me.ResetHit()
  me.SetName("to,navigation")
  me.SetHitScale(1)
  
  me.SetTimeout(2) -- Quite a short timeout
  
  me.SetHitCallback(#_HitCallback, me)
  me.SetTimeoutCallback(#_TimeoutCallback, me)
  
  if (ancestor.Start() = true) then
    GenLog(#debug, "NavTimeout::Start: Timer started!")
  else 
    GenLog(#error, "NavTimeout::Start: Timer NOT started!")
  end if
end

on Stop (me)
  ancestor.Stop()
end

on TriggerNavigation (me)
  me.Start()
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pTarget = ""
  me.pHistory = false
end

on _HitCallback (me)
  
end

on _TimeoutCallback (me)
  QI(#nav).DoNavigate()
  me.Stop()
end