-------------------------------------------------------------------------------
-- Name: class NetTextTimeout
-- Author: Jonathan Primeau
--
-- Description:
--     Takes care of the net text status.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
------------------------------------------------------------------------------- 

property ancestor              -- Parent


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class Timeout").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on Start (me)
  GenLog(#debug, "NetTextTimeout::Start: Starting timer...")
  
  me.ResetHit()
  me.SetName("to,checkNetTextStatus")
  me.SetHitScale(500) -- 0.5 second
  
  me.SetTimeout(0) -- Never timing out
  
  me.SetHitCallback(#_HitCallback, me)
  me.SetTimeoutCallback(#_TimeoutCallback, me)
  
  if (ancestor.Start() = true) then
    GenLog(#debug, "NetTextTimeout::Start: Timer started!")
  else 
    GenLog(#error, "NetTextTimeout::Start: Timer NOT started!")
  end if
end

on Stop (me)
  GenLog(#debug, "NetTextTimeout::Stop: Stopping timer...")
  ancestor.Stop()
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  
end

on _HitCallback (me)
  if (QI(#netText).CheckStatus() = "Complete") then
    QI(#netText).CheckDone()
  end if
end

on _TimeoutCallback (me)
  
end