-------------------------------------------------------------------------------
-- Name: class TerminalError
-- Author: Jonathan Primeau
--
-- Description:
--     Displays an error message until the terminal is OK
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
------------------------------------------------------------------------------- 

property ancestor              -- Parent


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class Window").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on Show (me)
  if (ancestor.IsVisible() = false) then
    lShowTerminalStatus = QI(#config).GetShowTerminalStatus()
    if (lShowTerminalStatus = true) then
      lTerminalErrorMsg = QI(#config).GetTerminalErrorMessage()
      
      GenLog(#debug, "TerminalError::Show: Showing...")
      
      ancestor.OpenWindow("msgdialog", #dialog)
      
      ancestor.CenterWindow()
      ancestor.GetMovieRef().InitDialog(me, "None", lTerminalErrorMsg)
      ancestor.ShowWindow()
      
      GenLog(#debug, "TerminalError::Show: Visible!")
    end if
  end if
end

on Hide (me, theButton)
  GenLog(#debug, "TerminalError::Hide: Hiding...")
  
  ancestor.HideWindow()
  ancestor.CloseWindow()
  
  GenLog(#debug, "TerminalError::Hide: Hidden!")
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  member("msgdialog,message").text = ""
end
