-------------------------------------------------------------------------------
-- Name: class VirtualKeyboard
-- Author: Jonathan Primeau
--
-- Description:
--     This class manages the virtual keyboard. It takes care of displaying
--     and hiding the keyboard
--
------------------------------------------------------------------------------- 

-------------------------------------------------------------------------------
-- P R O P E R T I E S
-------------------------------------------------------------------------------

property ancestor              -- Parent
property pFieldName
property pFrameName


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class Window").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  me.CloseWindow()
  
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end 

on Show (me, theFieldName, theValue, theType, theFrame)
  GenLog(#debug, "VirtualKeyboard::Show: Showing the virtual keyboard...")
  me.pFieldName = theFieldName
  me.pFrameName = theFrame
  
  me._CenterKeyboard()
  me.GetMovieRef().InitMovie(theType, string(theValue))
  me.SetType(#dialog)
  me.ShowWindow()
  
  -- Add a timeout listener so we can close the keyboard when a timeout occurs
  QI(#events).RegisterListener(#onTimeout, #_OnTimeout, me)
end


on Hide (me, theValue)
  GenLog(#debug, "VirtualKeyboard::Hide: Hiding the virtual keyboard...")
  
  me.HideWindow()
  
  -- Get rid of the timeout listener since the keyboard is closed
  QI(#events).UnregisterListener(#onTimeout, #_OnTimeout, me)
  
  me.pIsVisible = false
  if (theValue <> void) then
    QI(#web).MozillaSetEditField(me.pFieldName, theValue, me.pFrameName)
  end if
end

On UpdateMozField(me, theValue)
  -- This is called from the virtual keyboard each time a key is 
  -- pressed to update the field in the browser
  
  if (theValue <> void) then
    QI(#web).MozillaSetEditField(me.pFieldName, theValue, me.pFrameName)
  end if
End 
-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pFieldName = ""
  me.pFrameName = ""
  me.OpenWindow("Keyboard", #dialog)
end

on _CenterKeyboard (me)
  lCenterStagePos = ((_movie.stage.rect.right - _movie.stage.rect.left) / 2) + _movie.stage.rect.left
  lCenterKeyboard = (me.GetRect().right - me.GetRect().left) / 2
  
  lLeft = lCenterStagePos - lCenterKeyboard
  lTop = _movie.stage.rect.bottom - me.GetRect().height
  lRight = lLeft + me.GetRect().width
  lBottom = lTop + me.GetRect().height
  
  me.SetRect(rect(lLeft,lTop,lRight,lBottom))
end

on _OnTimeout (me)
  me.Hide()
end