-------------------------------------------------------------------------------
-- Name class  WaitTimeout
-- Author Jonathan Primeau
--
-- Description
--     Multi usage short timeout.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
------------------------------------------------------------------------------- 

property ancestor              -- Parent


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters
--     me (object) this pointer.
--
-- Return
--     me (object) A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class Timeout").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters
--     me (object) this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on Start (me)
  GenLog(#debug, "WaitTimeout Starting timer...")
  
  me.ResetHit()
  me.SetName("to,wait")
  me.SetHitScale(50) -- 0.05 second
  
  if (ancestor.Start() = true) then
    GenLog(#debug, "WaitTimeout Timer started!")
  else 
    GenLog(#error, "WaitTimeout Timer NOT started!")
  end if
end

on Stop (me)
  GenLog(#debug, "WaitTimeout Stopping timer...")
  ancestor.Stop()
  GenLog(#debug, "WaitTimeout Timer stopped!")
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters
--     me (object) this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  
end

on _HitCallback (me)
  
end